Crate jito_vault_core

Crate jito_vault_core 

Modules

burn_vault
config
The vault configuration account
delegation_state
discriminators
loader
Loader functions for the vault program.
vault
The vault is responsible for holding tokens and minting VRT tokens.
vault_ncn_slasher_operator_ticket
The VaultNcnSlasherOperatorTicket account tracks the amount an operator has been slashed by a slasher for a given node consensus network (NCN) and vault for a given epoch.
vault_ncn_slasher_ticket
The VaultNcnSlasherTicket account tracks a vault’s support for a node consensus network slasher. It can be enabled and disabled over time by the vault slasher admin.
vault_ncn_ticket
The VaultNcnTicket account tracks a vault supporting a node consensus network. It can be enabled and disabled over time by the vault NCN admin.
vault_operator_delegation
The VaultOperatorDelegation account tracks a vault’s delegation to an operator
vault_staker_withdrawal_ticket
The VaultStakerWithdrawalTicket account is used to represent a pending withdrawal from a vault by a staker. For every withdraw ticket, there’s an associated token account owned by the withdrawal ticket with the staker’s VRT.
vault_update_state_tracker

Constants

MAX_BPS