Modules
- burn_
vault - config
- The vault configuration account
- delegation_
state - discriminators
- loader
- Loader functions for the vault program.
- vault
- The vault is responsible for holding tokens and minting VRT tokens.
- vault_
ncn_ slasher_ operator_ ticket - The
VaultNcnSlasherOperatorTicketaccount tracks the amount an operator has been slashed by a slasher for a given node consensus network (NCN) and vault for a given epoch. - vault_
ncn_ slasher_ ticket - The
VaultNcnSlasherTicketaccount tracks a vault’s support for a node consensus network slasher. It can be enabled and disabled over time by the vault slasher admin. - vault_
ncn_ ticket - The
VaultNcnTicketaccount tracks a vault supporting a node consensus network. It can be enabled and disabled over time by the vault NCN admin. - vault_
operator_ delegation - The
VaultOperatorDelegationaccount tracks a vault’s delegation to an operator - vault_
staker_ withdrawal_ ticket - The
VaultStakerWithdrawalTicketaccount is used to represent a pending withdrawal from a vault by a staker. For every withdraw ticket, there’s an associated token account owned by the withdrawal ticket with the staker’s VRT. - vault_
update_ state_ tracker